#!/bin/bash

if [ -f ./global ]
then
. ./global
else
echo "No Global File!"
exit
fi

rm -rf tmpsql.sql

print_help ()
{
    echo "Usage: add_datasource -D <datasource template number> -H <host ID> --rrd <rrd file>"
    echo "Usage: add_datasource [-h | --help]"
    echo "Usage: add_datasource [--list] List Data Sources Templates"
    echo "Usage: add_datasource [--hostlist] List Hosts"
    echo "Usage: add_datasource [--datasourcelist] List Hosts"
}
 
if [ $# -lt 1 ]; then
    print_help
    exit $STATE_UNKNOWN
fi
 
while test -n "$1"; do
    case "$1" in
        --help)
            print_help
            exit
            ;;
        --list)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, name FROM data_template ORDER BY id;"
            exit
            ;;
        --hostlist)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, description, hostname FROM host ORDER BY id;"
            exit
            ;;
        --datasourcelist)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, data_template_id , host_id FROM data_local ORDER BY id;"
            exit
            ;;
        -h)
            print_help
            exit
            ;;
        -D)
            DATA_TEMPLATE_ID=$2
            shift
            ;;
        -H)
            HOST_ID=$2
            shift
            ;;
        -rrd)
            RRD_FILE=$2
            shift
            ;;
        *)
            echo "Unknown argument: $1"
            print_help
            exit
            ;;
    esac
    shift
done


##Check to make sure there are no Empty Values
if [ -z $HOST_ID ]
then
echo "Host ID EMPTY Must Supply HOST ID"
exit
fi
if [ -z $DATA_TEMPLATE_ID ]
then
echo "Data Source Template ID EMPTY Must Supply Templcate ID"
exit
fi
if [ -z $RRD_FILE ]
then
echo "RRD File Option Empty - Must Supply a RRD File"
exit
fi
if [ -f $RRD_FILE ]
then
:
else
echo "RRD File Supplied Does Not Exist"
exit
fi

TEST_TEST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM data_local WHERE data_template_id = '$DATA_TEMPLATE_ID' and host_id = '$HOST_ID';"|tr "\t" ","`

if [ -n "$TEST_TEST" ]
then
echo "Host With This Data Source Type Already Exist data template id: ($TEST_TEST)"
exit
fi

TEST_HOST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, description FROM host WHERE id = '$HOST_ID';"|tr "\t" ","`
TEST_HOSTDES=`echo $TEST_HOST|cut -d "," -f2`
TEST_HOSTNUM=`echo $TEST_HOST|cut -d "," -f1`
if [ "$HOST_ID" = "$TEST_HOSTNUM" ]
then
:
else
echo "Host Number Doesnt Exist in the host database!"
exit
fi

##############################################################################
##Get Highest ID Number and Add 1 from data_local ID number to be safe
NEXTAVAILIDDL=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from data_local;"`
NEXTAVAILIDDL=$((++NEXTAVAILIDDL))


##############################################################################
##Get Highest ID Number and Add 1 from data_template_data ID number to be safe
NEXTAVAILID=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from data_template_data;"`
NEXTAVAILID=$((++NEXTAVAILID))

#Extract Data Template Info

for LOOPER in `$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT * from data_template_data WHERE data_template_id = '$DATA_TEMPLATE_ID' AND local_data_template_data_id = '0' AND local_data_id = '0';"|sed 's/ /_REPLACE_/g'|tr "\t" ","|sed 's/,,/,NULL,/g'`
do

DTDATA=`echo $LOOPER|sed 's/_REPLACE_/ /g'`
FIELD_ID=`echo $DTDATA|cut -d "," -f1`
DATA_TEMP_ID=`echo $DTDATA|cut -d "," -f4`
DATA_INPUT_ID=`echo $DTDATA|cut -d "," -f5`
T_NAME=`echo $DTDATA|cut -d "," -f6`
DNAME=`echo $DTDATA|cut -d "," -f7`
T_ACTIVE=`echo $DTDATA|cut -d "," -f10`
ACTIVE=`echo $DTDATA|cut -d "," -f11`
T_RRD_STEP=`echo $DTDATA|cut -d "," -f12`
RRD_STEP=`echo $DTDATA|cut -d "," -f13`
T_RRA_ID=`echo $DTDATA|cut -d "," -f14`

if [ -z "$T_RRA_ID" ]
then
T_RRA_ID="NULL"
fi

DESCRIPT=`echo "$DNAME"|sed "s/|host_description|/$TEST_HOSTDES/g"`

## Create Instance for Data Source And Graph For Host and which Template to Use
echo "INSERT INTO data_local (id, data_template_id, host_id, snmp_query_id, snmp_index) VALUES" >> tmpsql.sql
echo "($NEXTAVAILIDDL, $DATA_TEMP_ID, $HOST_ID, 0, '');" >> tmpsql.sql
##Define Which Data Source Template to Use and define the RRD to Use
echo "INSERT INTO data_template_data (id, local_data_template_data_id, local_data_id, data_template_id, data_input_id, t_name, name, name_cache, data_source_path, t_active, active, t_rrd_step, rrd_step, t_rra_id) VALUES" >> tmpsql.sql
echo "($NEXTAVAILID, $FIELD_ID, $NEXTAVAILIDDL, $DATA_TEMP_ID, $DATA_INPUT_ID, $T_NAME, '$DNAME', '$DESCRIPT', '$RRD_FILE', $T_ACTIVE, '$ACTIVE', $T_RRD_STEP, $RRD_STEP, $T_RRA_ID);" >> tmpsql.sql
done

for LOOPER in `$mysqlcmd --batch -L -N -u$mysqluser -p$mysqlpassword $database -e "SELECT id from rra ORDER BY id;"`
do
echo "INSERT INTO data_template_data_rra (data_template_data_id, rra_id) VALUES" >> tmpsql.sql
echo "($NEXTAVAILID, $LOOPER);" >> tmpsql.sql
done

NEXTAID=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from data_template_rrd;"`

for LOOPER in `$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT * FROM data_template_rrd WHERE data_template_id = '$DATA_TEMPLATE_ID' and local_data_template_rrd_id = '0' and local_data_id = '0';"|tr "\t" ","|sed 's/,,/,NULL,/g'`
do
NEXTAID=$((++NEXTAID))
FIELD1=`echo $LOOPER|cut -d "," -f1`
FIELD5=`echo $LOOPER|cut -d "," -f5`
FIELD6=`echo $LOOPER|cut -d "," -f6`
FIELD7=`echo $LOOPER|cut -d "," -f7`
FIELD8=`echo $LOOPER|cut -d "," -f8`
FIELD9=`echo $LOOPER|cut -d "," -f9`
FIELD10=`echo $LOOPER|cut -d "," -f10`
FIELD11=`echo $LOOPER|cut -d "," -f11`
FIELD12=`echo $LOOPER|cut -d "," -f12`
FIELD13=`echo $LOOPER|cut -d "," -f13`
FIELD14=`echo $LOOPER|cut -d "," -f14`
FIELD15=`echo $LOOPER|cut -d "," -f15`
FIELD16=`echo $LOOPER|cut -d "," -f16`
FIELD17=`echo $LOOPER|cut -d "," -f17`

echo "INSERT INTO data_template_rrd (id, hash, local_data_template_rrd_id, local_data_id, data_template_id, t_rrd_maximum, rrd_maximum, t_rrd_minimum, rrd_minimum, t_rrd_heartbeat, rrd_heartbeat, t_data_source_type_id, data_source_type_id, t_data_source_name, data_source_name, t_data_input_field_id, data_input_field_id) VALUES" >> tmpsql.sql
echo "($NEXTAID, '', $FIELD1, $NEXTAVAILIDDL, $FIELD5, $FIELD6 , $FIELD7, $FIELD8, $FIELD9, $FIELD10, $FIELD11, $FIELD12, $FIELD13, $FIELD14, '$FIELD15', $FIELD16, $FIELD17);" >> tmpsql.sql
done

$mysqlcmd -u$mysqluser -p$mysqlpassword $database < tmpsql.sql
echo "data source $DESCRIPT created data-source-id: ($NEXTAVAILIDDL)"
#rm -rf tmpsql.sql
