#!/bin/bash

if [ -f ./global ]
then
. ./global
else
echo "No Global File!"
exit
fi

rm -rf tmpsql.sql

print_help ()
{
    echo "Usage: add_graph -G < Graph template number> -H <host ID> -D <datasourceid>"
    echo "Usage: add_graph [-h | --help]"
    echo "Usage: add_graph [--list] List Graph Templates"
    echo "Usage: add_graph [--hostlist] List Hosts"
    echo "Usage: add_graph [--graphlist] Graph List"
    echo "Usage: add_graph [--datasourcelist] List Datasources"
}
 
##############################################################################
## Pull options from the commad line
if [ $# -lt 1 ]; then
    print_help
    exit $STATE_UNKNOWN
fi
 
while test -n "$1"; do
    case "$1" in
        --help)
            print_help
            exit
            ;;
        --list)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, name FROM graph_templates ORDER BY id;"
            exit
            ;;
        --datasourcelist)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, data_template_id , host_id FROM data_local ORDER BY id;"
            exit
            ;;
        --hostlist)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, description, hostname FROM host ORDER BY id;"
            exit
            ;;
        --graphlist)
            $mysqlcmd --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, graph_template_id , host_id FROM graph_local ORDER BY id;"
            exit
            ;;
        -h)
            print_help
            exit
            ;;
        -G)
            GRAPH_TEMPLATE_ID=$2
            shift
            ;;
        -D)
            DATA_SOURCE_ID=$2
            shift
            ;;
        -H)
            HOST_ID=$2
            shift
            ;;
        *)
            echo "Unknown argument: $1"
            print_help
            exit
            ;;
    esac
    shift
done

##############################################################################
##Check to make sure there are no Empty Values
if [ -z $HOST_ID ]
then
echo "Host ID EMPTY Must Supply HOST ID"
exit
fi
if [ -z $GRAPH_TEMPLATE_ID ]
then
echo "Graph Template ID EMPTY Must Supply Template ID"
exit
fi
if [ -z $DATA_SOURCE_ID ]
then
echo "Data Source ID EMPTY Must Supply Data Source ID"
exit
fi

##############################################################################
## Check to see if the host already has this graph template associated!"
TEST_TEST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM graph_local WHERE graph_template_id = '$GRAPH_TEMPLATE_ID' and host_id = '$HOST_ID';"|tr "\t" ","`

if [ -n "$TEST_TEST" ]
then
echo "Host With This Graph Template Type Already Exist id: ($TEST_TEST)"
exit
fi

##############################################################################
##Check to see if the graph template exist
TEST_TEST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM graph_templates WHERE id = '$GRAPH_TEMPLATE_ID' ;"`

if [ -z "$TEST_TEST" ]
then
echo "Graph Template $GRAPH_TEMPLATE_ID does not exist!"
exit
fi

##############################################################################
## Check to make sure the host exist!
TEST_HOST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id, description FROM host WHERE id = '$HOST_ID';"|tr "\t" ","`
TEST_HOSTDES=`echo $TEST_HOST|cut -d "," -f2`
TEST_HOSTNUM=`echo $TEST_HOST|cut -d "," -f1`
if [ "$HOST_ID" = "$TEST_HOSTNUM" ]
then
:
else
echo "Host Number Doesnt Exist in the host database!"
exit
fi

##############################################################################
## Check to make sure the host exist!
TEST_TEST=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM data_local WHERE id = '$DATA_SOURCE_ID';"`
if [ -z "$TEST_TEST" ]
then
echo "Data Source Doesn't Exist in the database!"
exit
fi


##############################################################################
##Get Highest ID Number and Add 1 from graph_local ID number to be safe
NEXTAVAILIDDL=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from graph_local;"`
NEXTAVAILIDDL=$((++NEXTAVAILIDDL))

##############################################################################
##Get Highest ID Number and Add 1 from data_template_data ID number to be safe
NEXTAVAILID=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from graph_templates_graph;"`
NEXTAVAILID=$((++NEXTAVAILID))

##############################################################################
##Make graph from graph template specified for host specified
##Extract Data Template Info
for LOOPER in `$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT * from graph_templates_graph WHERE graph_template_id = '$GRAPH_TEMPLATE_ID' and local_graph_template_graph_id = '0' and local_graph_id = '0';"|sed 's/ /_REPLACE_/g'|tr "\t" ","`
do

DTDATA=`echo $LOOPER|sed 's/_REPLACE_/ /g'`
FIELD1=$NEXTAVAILID
FIELD2=`echo $DTDATA|cut -d "," -f1`
FIELD3=$NEXTAVAILIDDL
FIELD4=$GRAPH_TEMPLATE_ID
FIELD5=`echo $DTDATA|cut -d "," -f5`
FIELD6=`echo $DTDATA|cut -d "," -f6`
FIELD7=`echo $DTDATA|cut -d "," -f7`
FIELD8=`echo $DTDATA|cut -d "," -f8`
FIELD9=`echo $DTDATA|cut -d "," -f8|sed "s/|host_description|/$TEST_HOSTDES/g"`
FIELD10=`echo $DTDATA|cut -d "," -f10`
FIELD11=`echo $DTDATA|cut -d "," -f11`
FIELD12=`echo $DTDATA|cut -d "," -f12`
FIELD13=`echo $DTDATA|cut -d "," -f13`
FIELD14=`echo $DTDATA|cut -d "," -f14`
FIELD15=`echo $DTDATA|cut -d "," -f15`
FIELD16=`echo $DTDATA|cut -d "," -f16`
FIELD17=`echo $DTDATA|cut -d "," -f17`
FIELD18=`echo $DTDATA|cut -d "," -f18`
FIELD19=`echo $DTDATA|cut -d "," -f19`
FIELD20=`echo $DTDATA|cut -d "," -f20`
FIELD21=`echo $DTDATA|cut -d "," -f21`
FIELD22=`echo $DTDATA|cut -d "," -f22`
FIELD23=`echo $DTDATA|cut -d "," -f23`
FIELD24=`echo $DTDATA|cut -d "," -f24`
FIELD25=`echo $DTDATA|cut -d "," -f25`
FIELD26=`echo $DTDATA|cut -d "," -f26`
FIELD27=`echo $DTDATA|cut -d "," -f27`
FIELD28=`echo $DTDATA|cut -d "," -f28`
FIELD29=`echo $DTDATA|cut -d "," -f29`
FIELD30=`echo $DTDATA|cut -d "," -f30`
FIELD31=`echo $DTDATA|cut -d "," -f31`
FIELD32=`echo $DTDATA|cut -d "," -f32`
FIELD33=`echo $DTDATA|cut -d "," -f33`
FIELD34=`echo $DTDATA|cut -d "," -f34`
FIELD35=`echo $DTDATA|cut -d "," -f35`
FIELD36=`echo $DTDATA|cut -d "," -f36`
FIELD37=`echo $DTDATA|cut -d "," -f37`
FIELD38=`echo $DTDATA|cut -d "," -f38`
FIELD39=`echo $DTDATA|cut -d "," -f39`

if [ -z "$FIELD5" ]
then
FIELD5=0
fi

if [ -z "$FIELD7" ]
then
FIELD7=0
fi

if [ -z "$FIELD10" ]
then
FIELD10=0
fi

if [ -z "$FIELD12" ]
then
FIELD12=0
fi
if [ -z "$FIELD14" ]
then
FIELD14=0
fi

if [ -z "$FIELD16" ]
then
FIELD16=0
fi

if [ -z "$FIELD18" ]
then
FIELD18=0
fi

if [ -z "$FIELD20" ]
then
FIELD20=0
fi

if [ -z "$FIELD22" ]
then
FIELD22=0
fi

if [ -z "$FIELD24" ]
then
FIELD24=0
fi

if [ -z "$FIELD26" ]
then
FIELD26=0
fi

if [ -z "$FIELD28" ]
then
FIELD28=0
fi

if [ -z "$FIELD30" ]
then
FIELD30=0
fi

if [ -z "$FIELD32" ]
then
FIELD32=0
fi

if [ -z "$FIELD34" ]
then
FIELD34=0
fi

if [ -z "$FIELD36" ]
then
FIELD36=0
fi

if [ -z "$FIELD38" ]
then
FIELD38=0
fi


echo "INSERT INTO graph_local (id, graph_template_id, host_id, snmp_query_id, snmp_index) VALUES" >> tmpsql.sql
echo "($NEXTAVAILIDDL, $GRAPH_TEMPLATE_ID, $HOST_ID, 0, '');" >> tmpsql.sql
echo "INSERT INTO graph_templates_graph (id, local_graph_template_graph_id, local_graph_id, graph_template_id, t_image_format_id, image_format_id, t_title, title, title_cache, t_height, height, t_width, width, t_upper_limit, upper_limit, t_lower_limit, lower_limit, t_vertical_label, vertical_label, t_auto_scale, auto_scale, t_auto_scale_opts, auto_scale_opts, t_auto_scale_log, auto_scale_log, t_auto_scale_rigid, auto_scale_rigid, t_auto_padding, auto_padding, t_base_value, base_value, t_grouping, grouping, t_export, export, t_unit_value, unit_value, t_unit_exponent_value, unit_exponent_value) VALUES" >> tmpsql.sql
echo "( $FIELD1, $FIELD2, $FIELD3, $FIELD4, '$FIELD5', $FIELD6, '$FIELD7', '$FIELD8', '$FIELD9', '$FIELD10', $FIELD11, '$FIELD12', $FIELD13, '$FIELD14', '$FIELD15', '$FIELD16', '$FIELD17', '$FIELD18', '$FIELD19', '$FIELD20', '$FIELD21', '$FIELD22', $FIELD23, '$FIELD24', '$FIELD25', '$FIELD26', '$FIELD27', '$FIELD28', '$FIELD29', '$FIELD30', $FIELD31, '$FIELD32', '$FIELD33', '$FIELD34', '$FIELD35', '$FIELD36', '$FIELD37', '$FIELD38', '$FIELD39');" >> tmpsql.sql

done

##############################################################################
##Match cdef's to graph items
NEXT_GRAPH_TEMPLATES_ID=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT MAX(id) as max_id from graph_templates_item;"`

for GRAPH_TEMPLATE_INPUT in `$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM graph_template_input WHERE graph_template_id = '$GRAPH_TEMPLATE_ID';"`
do

for GRAPH_TEMPLATE_INPUT_DEF in `$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT graph_template_item_id FROM graph_template_input_defs WHERE graph_template_input_id = '$GRAPH_TEMPLATE_INPUT';"`
do
NEXT_GRAPH_TEMPLATES_ID=$((++NEXT_GRAPH_TEMPLATES_ID))

GRAPH_TEMPLATES_ITEM=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT * FROM graph_templates_item WHERE id = '$GRAPH_TEMPLATE_INPUT_DEF';"|tr "\t" ","`

FIELD1=$NEXT_GRAPH_TEMPLATES_ID
FIELD2=""
FIELD3=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f1`
FIELD4=$NEXTAVAILIDDL
FIELD5=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f5`
FIELD6=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f6`
FIELD7=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f7`
FIELD8=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f8`
FIELD9=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f9`
FIELD10=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f10`
FIELD11=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f11`
FIELD12=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f12`
FIELD13=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f13`
FIELD14=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f14`
FIELD15=`echo $GRAPH_TEMPLATES_ITEM|cut -d "," -f15`

DATA_TEMPLATE_RRD=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT * FROM data_template_rrd WHERE id = '$FIELD6';"|tr "\t" ","`

RRDFIELD=`echo $DATA_TEMPLATE_RRD|cut -d "," -f15`

IDFIELD1=`$mysqlcmd -L -N --batch -u$mysqluser -p$mysqlpassword $database -e "SELECT id FROM data_template_rrd WHERE local_data_id = '$DATA_SOURCE_ID' and data_source_name = '$RRDFIELD';"|tr "\t" ","`

if [ -z "$RRDFIELD" ]
then
echo "Graph Template Field Incorrectly Set or Empty"
exit
fi

echo "INSERT INTO graph_templates_item ( id, hash, local_graph_template_item_id, local_graph_id, graph_template_id, task_item_id, color_id, graph_type_id, cdef_id, consolidation_function_id, text_format, value, hard_return, gprint_id, sequence) VALUES" >> tmpsql.sql
echo "($FIELD1, '$FIELD2', $FIELD3, $FIELD4, $FIELD5, $IDFIELD1, $FIELD7, $FIELD8, $FIELD9, $FIELD10, '$FIELD11', '$FIELD12', '$FIELD13', $FIELD14, $FIELD15);" >> tmpsql.sql

done

done

$mysqlcmd -u$mysqluser -p$mysqlpassword $database < tmpsql.sql
echo "Graph Created Graph ID: ($NEXTAVAILIDDL)"
rm -rf tmpsql.sql
